package com.ynet.life.security.crypto;

import java.io.File;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.text.SimpleDateFormat;
import java.util.Date;
import javax.crypto.spec.DESKeySpec;
import javax.crypto.spec.SecretKeySpec;

/* loaded from: com_ynet_life_security_crypto.jar:com/ynet/life/security/crypto/DEStester.class */
public class DEStester {
    private static final String DES_KEY = "CMMSGIBI";
    private static final String TRIPLE_DES_KEY = "FOXCONNTECHNOLOGYGROUPCN";
    public static DESKeySpec DESKeySpec;
    public static SecretKeySpec tripleDESKeySpec;
    public static final String[] TEST_FILES = {"C:\\xml\\391Sample.xml", "C:\\xml\\2134Sample.xml", "C:\\xml\\4876Sample.xml", "C:\\xml\\8381Sample.xml", "C:\\xml\\12571Sample.xml"};
    public static final String[] TEST_FILES_ANDROID = {"C:\\xml\\391Sample.xml", "C:\\xml\\375Sample.xml", "C:\\xml\\353Sample.xml"};
    public static final String[] ENCRYPTED_FILES = {"C:\\xml\\Enc391Sample.xml", "C:\\xml\\Enc2134Sample.xml", "C:\\xml\\Enc4876Sample.xml", "C:\\xml\\Enc8381Sample.xml", "C:\\xml\\Enc12571Sample.xml"};
    public static final String[] DECRYPTED_FILES = {"C:\\xml\\Dec391Sample.xml", "C:\\xml\\Dec2134Sample.xml", "C:\\xml\\Dec4876Sample.xml", "C:\\xml\\Dec8381Sample.xml", "C:\\xml\\Dec12571Sample.xml"};
    public static final String[] TEST_STRING = {"genius is one percent inspiration and ninety-nine percent perspiration!", "天才就是百分之一的灵感加上百分之九十九的汗水！", "where there is a will there is a way!", "有志者，事竟成！", "he who laughs last laughs best!", "笑到最后，笑得最好。"};

    public static void testGenerateDESKey() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試DES生成Key加密解密");
        DESKeySpec = DESCrypto.getDESKeySpec();
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < TEST_STRING.length; i++) {
            String cipherText = DESCrypto.encrypt(TEST_STRING[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testLoadDESKey() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試DES Load Key加密解密");
        DESKeySpec = DESCrypto.getDESKeySpecFromString(DES_KEY);
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < TEST_STRING.length; i++) {
            String cipherText = DESCrypto.encrypt(TEST_STRING[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testGenerateTripleDESKey() throws NoSuchAlgorithmException, IOException {
        System.out.println("測試Triple DES生成Key加密解密");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpec();
        System.out.println(DESCrypto.getTripleDESKeyString());
        for (int i = 0; i < TEST_STRING.length; i++) {
            String cipherText = DESCrypto.tripleDESEncrypt(TEST_STRING[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testLoadTripleDESKey() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試Triple DES Load Key加密解密");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpecFromString(TRIPLE_DES_KEY);
        System.out.println(DESCrypto.getTripleDESKeyString());
        for (int i = 0; i < TEST_STRING.length; i++) {
            String cipherText = DESCrypto.tripleDESEncrypt(TEST_STRING[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testDESFile() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試DES生成Key文件加密解密");
        DESKeySpec = DESCrypto.getDESKeySpec();
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < TEST_FILES.length; i++) {
            System.out.println("加密文件：" + TEST_FILES[i] + " 開始 " + getCurrentDateTime());
            DESCrypto.encryptFile(new File(TEST_FILES[i]), ENCRYPTED_FILES[i], false);
            System.out.println("加密文件：" + TEST_FILES[i] + " 結束 " + getCurrentDateTime());
            System.out.println("解密文件：" + ENCRYPTED_FILES[i] + " 開始 " + getCurrentDateTime());
            DESCrypto.decryptFile(new File(ENCRYPTED_FILES[i]), DECRYPTED_FILES[i], false);
            System.out.println("解密文件：" + ENCRYPTED_FILES[i] + " 結束 " + getCurrentDateTime());
        }
    }

    public static void testTripleDESFile() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試Triple DES生成Key文件加密解密");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpec();
        System.out.println(DESCrypto.getTripleDESKeyString());
        for (int i = 0; i < TEST_FILES.length; i++) {
            System.out.println("加密文件：" + TEST_FILES[i] + " 開始 " + getCurrentDateTime());
            DESCrypto.encryptFile(new File(TEST_FILES[i]), ENCRYPTED_FILES[i], true);
            System.out.println("加密文件：" + TEST_FILES[i] + " 結束 " + getCurrentDateTime());
            System.out.println("解密文件：" + ENCRYPTED_FILES[i] + " 開始 " + getCurrentDateTime());
            DESCrypto.decryptFile(new File(ENCRYPTED_FILES[i]), DECRYPTED_FILES[i], true);
            System.out.println("解密文件：" + ENCRYPTED_FILES[i] + " 結束 " + getCurrentDateTime());
        }
    }

    public static void testOCDESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] ocEncrypted = {"7a6409d93de46a2f507db521abbb12d67522edd282ee6d6ebfd2c4ef079cf2ee1afea1c13b2d9eec786cc30b08043016dfb4b0829a2b884ecf2e5042665687b936c25466eeac51fc", "d05e2780e430f5b8d04da0094001fe59fef5e31ca8cd0aa53571df39f97c7c9061f97085997476979380c1321dc8df527cd8997860a6487739a87236328c4a431295cd17515d2109", "9b3c7c6f0ce2dc7622f1f1ce1855b311d7ceb74aacd4d92622f1f1ce1855b311f0425b1afb4c2285", "8cd8e047bb348b2603ed34b6e14d01a6103db83c19b163fc", "afe60f1162736a36fbf2e35ed4f24bc40a1c595092df320de6f22883c22bdc3f", "050959f1d3d68a6935d8f779b9c612ea85170f7d931a61780a055ece4ae004ec"};
        System.out.println("測試DES Load OC Key and Enrypted text 加密解密");
        DESKeySpec = DESCrypto.getDESKeySpecFromBytes("434d4d53474942494954535344455631".toUpperCase());
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < 6; i++) {
            String cipherText = ocEncrypted[i].toUpperCase();
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testOC3DESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] ocEncrypted = {"2f92bb7ae8d555030ec00155b15749a39f3f74b5cca7547b3611c19be7ff35c64069ef68b4d00e79164ca5ccc48c8790b37b8221321709ea739195db9f52241e99da5447c34dcd3f", "1f33cdfe4eff5d7bc3e29aee0d59a10c8ddfeac16f68277fc22b1c2c54ca09da18b3770352106e4e55e826ecfb3329d5858335430c6f5db2f1b29c7c77d6b01625c2330b20f3dc07", "402b236ed25661b2dc7834f82a4b714ad1145469fbd48694dc7834f82a4b714a202ec60ef80ae9a6", "69404ba98e3a4730d8c7307d3fc7e85b8501a1eb1ce14c03", "f1a148028ad240c33a83cb99f8d94a4fa2f99aa39221ac3db9fa1088a1917049", "7c9b876ffa4527db0ec3e88458084d6ffcce9fcc171d65bc63d5b94b51cd9eb5"};
        System.out.println("測試DES Load OC Key and Enrypted text 加密解密");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpecFromBytes("464f58434f4e4e544543484e4f4c4f475947524f5550434e".toUpperCase());
        System.out.println(DESCrypto.getTripleDESKeyString());
        for (int i = 0; i < 6; i++) {
            String cipherText = ocEncrypted[i].toUpperCase();
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testAndroidDESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] androidEncrypted = {"6E137D0B986D94D4D10DF3DFBE11D8A5F1A1FC212A6E9530DA4F04EEF0B202272289C291E471101101F8582667E022B553C4AAADB9EBB8ED2A065C81D16170D6ECF3443603AE45B3", "BD00AB88F09231FAA194F2C74946C434B6A445FF818D5FD7A516125DDAA71CC07D846D5E06DBC78DF50FD9831F305D3B17545751443F3A6FC5BBBEE97C9CCB1A6927EE7B7D372E7F", "A61D6137FCD846BD840A81A36243874838D786CA209A46E3840A81A3624387480BB0F71EFDD3C5C0", "21FC65CEF0367555B3D70DC4BF426398A1746B9440B0727C9F00095283001972", "5424B3C3DB6639940545706CDA8E38015F87622C2BCBB0090B8758E2010C8D0C", "4CB1DB37220C1F41FE4054ED3B1B503C9DB53B6DCBDC4EC3EFF3E0E21D3E5034"};
        System.out.println("測試DES Load Android Key and Enrypted text 加密解密");
        DESKeySpec = DESCrypto.getDESKeySpecFromBytes("40BF469D3D19BA46".toUpperCase());
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < 6; i++) {
            String cipherText = androidEncrypted[i].toUpperCase();
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testAndroid3DESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] androidEncrypted = {"AD7C83756E2256B0421F0465710680417D071E3CDDA7545764EE41BD69ACA9145B2904C8A097C58F8A7FB58C12471A96F8B9EA63AF26EAA13EE7D97C336415BF5EBFCFD254961457", "F57FE57C2838886862A48D9BA6DA9A18C961C831A492F1A2E5515E368899416D646D66D1A81A68432A0FAE6B230D7221A32D1A35373F62382510A2FA89A1B25D7E68EE96ACE7B604", "EEA476256F1A7662A1AB83478DC61D0E53450AA4D97ED802A1AB83478DC61D0E046793D64D25F187", "009835ED65795A9C6DC15147A5CED46FCDE0629D78466C4EEBBFB307FA445A31", "58FB4E3E70717E163C7A7408EFED7C63E347CE52EC3098681F2698A3E42E832C", "9706ACDE253D36DD26303A9AEAED70975766BB678BE35AA2ED193DA3897F21CE"};
        System.out.println("測試DES Load Android Key and Enrypted text 加密解密");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpecFromBytes("5240855810D0EF1A5DE0CB5BC8130E5129E9516445CD8A54".toUpperCase());
        System.out.println(DESCrypto.getTripleDESKeyString());
        for (int i = 0; i < 6; i++) {
            String cipherText = androidEncrypted[i].toUpperCase();
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testJSDESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] jsEncrypted = {"3b94facda0bec2ddb434a2e714e977fb", "3b94facda0bec2dd983b3892c88bc6a3c95c03e4f5e17841", "3b94facda0bec2dd989dc10e53c773c43ae5e854a1900351", "3b94facda0bec2dd43b4526017f0b4baf964c44752e786db", "3b94facda0bec2dde77d23512d3b9b6213bd4f411884e016", "3b94facda0bec2dd12664df83fbc4dd3542c8e8cbff3073f", "3b94facda0bec2dd472d9b7b43aef0bfcd037deb36fe85c2", "3b94facda0bec2dd143719ba9e720d788299bbd69cc0a2b1", "3b94facda0bec2dd77c52e6340449434b434a2e714e977fb", "3b94facda0bec2dd77c52e63404494340ac05d1a6305c41dc95c03e4f5e17841"};
        System.out.println("測試DES Load JS String Key and Enrypted text 加密解密");
        DESKeySpec = DESCrypto.getDESKeySpecFromString("kFR0a_38");
        System.out.println(DESCrypto.getDESKeyString());
        String strSuffix = DESCrypto.getRandomSuffix();
        for (int i = 0; i < 10; i++) {
            String cipherText = String.valueOf(jsEncrypted[i].toUpperCase().substring(0, jsEncrypted[i].length() - 16)) + strSuffix;
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText.trim());
        }
    }

    public static void testJS3DESEncryption() throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
        String[] jsEncrypted = {"0f3d0b698abf4282b4d073ea2c41e1bc", "7095ed2b7b548762c2c11d3df9fa94ca", "7095ed2b7b54876285f9de50059fd23f81802b4a44f0a6bc", "7095ed2b7b548762c9609433f7a0556dc2c11d3df9fa94ca", "0dfde5f919fc981cce019abac80931b2c713438900350886ce019abac80931b2383d64c1dd6e8092b4d073ea2c41e1bc", "785611930ad1c793e6f65d15c47565eccdfc84295edc1c0854513f607797dc827ef1d547a8a0f6ef"};
        System.out.println("測試DES Load JavaScript 3DES Key and Encrypted text 加密解密");
        tripleDESKeySpec = DESCrypto.getJSTripleDESKeySpecFromString("cZzvzmbjZRWkdjZwj2BNWT1P");
        String strSuffix = DESCrypto.get3DESRandomSuffix();
        System.out.println(strSuffix);
        for (int i = 0; i < 6; i++) {
            String cipherText = String.valueOf(jsEncrypted[i].toUpperCase().substring(0, jsEncrypted[i].length() - 16)) + strSuffix;
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void testDESStringKeyForJS() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試DES String Key加密解密 for JavaScript");
        DESKeySpec = DESCrypto.getDESKeySpecFromString("12345678");
        String[] javaString = {"Genius is one percent inspiration and ninety-nine percent perspiration", "Where there is a will there is a way", "He who laughs last laughs best", "abcdefgh", "12345"};
        System.out.println(DESCrypto.getDESKeyString());
        for (int i = 0; i < 5; i++) {
            String cipherText = DESCrypto.encrypt(javaString[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.decrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static void test3DESStringKeyForJS() throws InvalidKeyException, NoSuchAlgorithmException, IOException {
        System.out.println("測試DES String Key加密解密 for JavaScript");
        tripleDESKeySpec = DESCrypto.getTripleDESKeySpecFromString("cZzvzmbjZRWkdjZwj2BNWT1P");
        System.out.println(DESCrypto.getTripleDESKeyString());
        String[] javaString = {"Genius is one percent inspiration and ninety-nine percent perspiration", "Where there is a will there is a way", "He who laughs last laughs best", "abcdefgh", "12345"};
        for (int i = 0; i < 5; i++) {
            String cipherText = DESCrypto.tripleDESEncrypt(javaString[i]);
            System.out.println("密文：");
            System.out.println(cipherText);
            String plainText = DESCrypto.tripleDESDecrypt(cipherText);
            System.out.println("明文：");
            System.out.println(plainText);
        }
    }

    public static String getCurrentDateTime() {
        return new SimpleDateFormat("yyyy-MM-dd hh:mm:ss").format(new Date());
    }

    /* JADX WARN: Not initialized variable reg: 0, insn: 0x0006: INVOKE (r0 I:java.lang.Exception) VIRTUAL call: java.lang.Exception.printStackTrace():void A[MD:():void (c)], block:B:7:0x0005 */
    public static void main(String[] args) {
        Exception printStackTrace;
        try {
            testJS3DESEncryption();
        } catch (Exception e) {
            printStackTrace.printStackTrace();
        }
    }
}
